# OARepo model builder

A library and command-line tool to generate invenio model project from a single model file.

Documentation for the model format and examples are at [https://narodni-repozitar.github.io/developer-docs/docs/technology/invenio/nrp-toolchain/edit-metadata](https://narodni-repozitar.github.io/developer-docs/docs/technology/invenio/nrp-toolchain/edit-metadata)

To compile your model into invenio sources, run

```bash
oarepo-compile-model <model.yaml> --output-directory <output-dir>
```